@@ -26,6 +26,17 @@ from .arch import Arch, register_arch, Endness, Register
 from .tls import TLSArchInfo
 from .archerror import ArchError
 
+
+_NATIVE_FUNCTION_PROLOGS = [
+        br"\x55\x48\x89\xe5", # push rbp; mov rbp, rsp
+        br"\x48[\x83,\x81]\xec[\x00-\xff]", # sub rsp, xxx
+    ]
+# every function prolog can potentially be prefixed with endbr64
+_endbr64 = b"\xf3\x0f\x1e\xfa"
+_prefixed = [(_endbr64 + prolog) for prolog in _NATIVE_FUNCTION_PROLOGS]
+_FUNCTION_PROLOGS = _prefixed + _NATIVE_FUNCTION_PROLOGS
+
+
 class ArchAMD64(Arch):
     def __init__(self, endness=Endness.LE):
         if endness != Endness.LE:
@@ -49,6 +60,8 @@ class ArchAMD64(Arch):
             self.registers['xmm6'][0]: 6,
             self.registers['xmm7'][0]: 7
         } if _pyvex is not None else None
+        if _unicorn:
+            self.unicorn_flag_register = _unicorn.x86_const.UC_X86_REG_EFLAGS
 
     @property
     def capstone_x86_syntax(self):
@@ -132,10 +145,7 @@ class ArchAMD64(Arch):
     uc_mode = (_unicorn.UC_MODE_64 + _unicorn.UC_MODE_LITTLE_ENDIAN) if _unicorn else None
     uc_const = _unicorn.x86_const if _unicorn else None
     uc_prefix = "UC_X86_" if _unicorn else None
-    function_prologs = {
-        br"\x55\x48\x89\xe5", # push rbp; mov rbp, rsp
-        br"\x48[\x83,\x81]\xec[\x00-\xff]", # sub rsp, xxx
-    }
+    function_prologs = _FUNCTION_PROLOGS
     function_epilogs = {
         br"\xc9\xc3", # leaveq; retq
         br"([^\x41][\x50-\x5f]{1}|\x41[\x50-\x5f])\xc3", # pop <reg>; retq
@@ -174,12 +184,12 @@ class ArchAMD64(Arch):
                                                    ('si', 0, 2),
                                                    ('sil', 0, 1),
                                                    ('sih', 1, 1)],
-                 general_purpose=True, argument=True),
+                 general_purpose=True, argument=True, linux_entry_value='argv'),
         Register(name='rdi', size=8, subregisters=[('edi', 0, 4),
                                                    ('di', 0, 2),
                                                    ('dil', 0, 1),
                                                    ('dih', 1, 1)],
-                 general_purpose=True, argument=True),
+                 general_purpose=True, argument=True, linux_entry_value='argc'),
         Register(name='r8', size=8, subregisters=[('r8d', 0, 4),
                                                   ('r8w', 0, 2),
                                                   ('r8b', 0, 1)],
@@ -315,7 +325,7 @@ class ArchAMD64(Arch):
                                                       ('xmm15hq', 8, 8),
                                                       ('ymm15hx', 16, 16)],
                  vector=True),
-        Register(name='ftop', size=4, floating_point=True, default_value=(0, False, None)),
+        Register(name='ftop', size=4, floating_point=True, default_value=(0, False, None), artificial=True),
         Register(name='fpreg', size=64, subregisters=[('mm0', 0, 8),
                                                       ('mm1', 8, 8),
                                                       ('mm2', 16, 8),
@@ -329,7 +339,7 @@ class ArchAMD64(Arch):
                  floating_point=True, default_value=(0, False, None)),
         Register(name='fpround', size=8, floating_point=True, default_value=(0, False, None)),
         Register(name='fc3210', size=8, floating_point=True),
-        Register(name='emnote', size=4),
+        Register(name='emnote', size=4, artificial=True),
         Register(name='cmstart', size=8),
         Register(name='cmlen', size=8),
         Register(name='nraddr', size=8),
