@@ -3,7 +3,7 @@ archinfo is a collection of classes that contain architecture-specific informati
 It is useful for cross-architecture tools (such as pyvex).
 """
 
-__version__ = (8, 20, 7, 6)
+__version__ = (9, 0, 6642)
 
 if bytes is str:
     raise Exception("This module is designed for python 3 only. Please install an older version to use python 2.")
@@ -27,6 +27,7 @@ from .arch_amd64    import ArchAMD64
 from .arch_x86      import ArchX86
 from .arch_arm      import ArchARM, ArchARMEL, ArchARMHF, ArchARMCortexM
 from .arch_aarch64  import ArchAArch64
+from .arch_avr      import ArchAVR8
 from .arch_ppc32    import ArchPPC32
 from .arch_ppc64    import ArchPPC64
 from .arch_mips32   import ArchMIPS32
