@@ -266,6 +266,40 @@ class Arch:
                 if hasattr(self.uc_const, reg_name):
                     self.uc_regs[r] = getattr(self.uc_const, reg_name)
 
+            # Register blacklist
+            reg_blacklist = ('cs', 'ds', 'es', 'fs', 'gs', 'ss', 'mm0', 'mm1', 'mm2', 'mm3', 'mm4', 'mm5', 'mm6', 'mm7', 'gdt', 'ldt')
+            self.reg_blacklist = []
+            self.reg_blacklist_offsets = []
+            for register in self.register_list:
+                if register.name in reg_blacklist:
+                    self.reg_blacklist.append(register.name)
+                    self.reg_blacklist_offsets.append(register.vex_offset)
+
+            # Artificial registers offsets
+            self.artificial_registers_offsets = []
+            for reg_name in self.artificial_registers:
+                reg = self.get_register_by_name(reg_name)
+                self.artificial_registers_offsets.extend(range(reg.vex_offset, reg.vex_offset + reg.size))
+
+            # VEX register offset to unicorn register ID map
+            self.vex_to_unicorn_map = {}
+            pc_reg_name = self.get_register_by_name("pc")
+            for reg_name, unicorn_reg_id in self.uc_regs.items():
+                if reg_name == pc_reg_name:
+                    continue
+
+                vex_reg = self.get_register_by_name(reg_name)
+                self.vex_to_unicorn_map[vex_reg.vex_offset] = unicorn_reg_id
+
+            # CPU flag registers
+            cpu_flag_registers = {'d': 10, 'ac': 18, 'id': 21}
+            self.cpu_flag_register_offsets_and_bitmasks_map = {}
+            for flag_reg, bitmask in cpu_flag_registers.items():
+                if flag_reg in self.registers:
+                    flag_reg_offset = self.get_register_offset(flag_reg)
+                    flag_bitmask = (1 << bitmask)
+                    self.cpu_flag_register_offsets_and_bitmasks_map[flag_reg_offset] = flag_bitmask
+
 
     def copy(self):
         """
@@ -389,8 +423,7 @@ class Arch:
         A Capstone instance for this arch
         """
         if _capstone is None:
-            l.warning("Capstone is not installed!")
-            return None
+            raise Exception("Capstone is not installed!")
         if self.cs_arch is None:
             raise ArchError("Arch %s does not support disassembly with Capstone" % self.name)
         if self._cs is None:
@@ -406,8 +439,7 @@ class Arch:
         """
         if self._ks is None:
             if _keystone is None:
-                l.warning("Keystone is not installed!")
-                return None
+                raise Exception("Keystone is not installed!")
             if self.ks_arch is None:
                 raise ArchError("Arch %s does not support disassembly with Keystone" % self.name)
             self._ks = _keystone.Ks(self.ks_arch, self.ks_mode)
@@ -684,6 +716,13 @@ class Arch:
     uc_const = None
     uc_prefix = None
     uc_regs = None
+    artificial_registers_offsets = None
+    artificial_registers = set()
+    cpu_flag_register_offsets_and_bitmasks_map = None
+    reg_blacklist = None
+    reg_blacklist_offsets = None
+    unicorn_flag_register = None
+    vex_to_unicorn_map = None
 
     call_pushes_ret = False
     initial_sp = 0x7fff0000
